@@ -30,6 +30,7 @@ from Persistence import Persistent
 from webdav.Lockable import wl_isLocked
 from xml.dom.minidom import getDOMImplementation
 from xml.dom.minidom import parseString
+from xml.parsers.expat import ExpatError
 import xmlrpclib
 from cStringIO import StringIO
 import traceback
@@ -41,7 +42,6 @@ import transaction
 from zope import event
 from Products.Archetypes.event import ObjectEditedEvent
 from zope.component import getUtility
-from dm.sharedresource import get_resource
 try:
     from plone.app.async.interfaces import IAsyncService
     ASYNC = True
@@ -52,6 +52,7 @@ from migration.migration import migrate
 from index.PlominoIndex import PlominoIndex
 from exceptions import PlominoScriptException, PlominoDesignException
 from PlominoUtils import asUnicode
+from PlominoUtils import escape_xml_illegal_chars
 from Products.CMFPlomino import get_utils
 from Products.CMFPlomino import plomino_profiler
 # get AT specific schemas for each Plomino class
@@ -107,8 +108,7 @@ class PlominoDesignManager(Persistent):
         """
         async = getUtility(IAsyncService)
         job = async.queueJob(run_refreshdb, self)
-        all_db_status = get_resource("plomino_status", dict)
-        all_db_status[self.absolute_url_path()] = job
+        self.setStatus("Waiting")
 
     security.declareProtected(DESIGN_PERMISSION, 'refreshDB')
     def refreshDB(self):
@@ -161,7 +161,7 @@ class PlominoDesignManager(Persistent):
         for f_obj in self.getForms() :
             for f in f_obj.getFormFields():
                 if f.getToBeIndexed() :
-                    index.createFieldIndex(f.id, f.getFieldType())
+                    index.createFieldIndex(f.id, f.getFieldType(), indextype=f.getIndexType())
         logger.info('Field indexing initialized')
 
         #declare all the view formulas and columns index entries
@@ -808,7 +808,10 @@ class PlominoDesignManager(Persistent):
                 if len(items)>0:
                     # export field settings
                     str_items = xmlrpclib.dumps((items,), allow_none=1)
-                    dom_items = parseString(str_items)
+                    try: 
+                        dom_items = parseString(str_items)
+                    except ExpatError:
+                        dom_items = parseString(escape_xml_illegal_chars(str_items))
                     node.appendChild(dom_items.documentElement)
         if not isDatabase:
             elementslist = obj.objectIds()
@@ -1012,7 +1015,7 @@ class PlominoDesignManager(Persistent):
             if len(settings_values) > 0:
                 adapt = obj.getSettings()
                 for key in settings_values.keys():
-                    setattr(adapt, key, settings_values[key])
+                    getattr(adapt, 'parameters')[key] = settings_values[key]
 
     security.declareProtected(DESIGN_PERMISSION, 'importDbSettingsFromXML')
     def importDbSettingsFromXML(self, node):
