@@ -40,6 +40,8 @@ from zope.annotation import IAttributeAnnotatable
 from zope.app.container.contained import Contained
 
 import simplejson as json
+from copy import deepcopy
+from persistent.dict import PersistentDict
 
 import logging
 logger = logging.getLogger('Plomino')
@@ -81,7 +83,7 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
         """
         CMFBTreeFolder.__init__(self, id)
         self.id = id
-        self.items = {}
+        self.items = PersistentDict()
         self.plomino_modification_time = DateTime().toZone('UTC')
 
     security.declarePublic('checkBeforeOpenDocument')
@@ -129,7 +131,7 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
         """
         """
         if(self.items.has_key(name)):
-            return self.items[name]
+            return deepcopy(self.items[name])
         else:
             return default
 
@@ -216,7 +218,7 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
             item = REQUEST.get('item', item)
             formid = REQUEST.get('formid', formid)
         if not item:
-            return json.dumps(self.items)
+            return json.dumps(self.items.data)
         
         if not formid:
             form = self.getForm()
