@@ -20,10 +20,13 @@ from HttpUtils import authenticateAndLoadURL, authenticateAndPostToURL
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlomino.exceptions import PlominoReplicationException
 from Products.CMFPlomino.PlominoUtils import StringToDate
+from Products.CMFPlomino.PlominoUtils import escape_xml_illegal_chars
 import re
 from Persistence import Persistent
+from persistent.dict import PersistentDict
 from xml.dom.minidom import getDOMImplementation
 from xml.dom.minidom import parseString
+from xml.parsers.expat import ExpatError
 import xmlrpclib
 import codecs
 import os
@@ -426,9 +429,9 @@ class PlominoReplicationManager(Persistent):
         """ exports document to remoteUrl
             send object as a xml stream via HTTP multipart POST
         """
-        id=doc.id
-        xmlstring=self.exportAsXML(docids=[id])
-        result = authenticateAndPostToURL(remoteUrl+"/importFromXML", username, password, '%s.%s' % (id, 'xml'), xmlstring.encode('utf-8'))
+        i = doc.id
+        xmlstring=self.exportAsXML(docids=[i])
+        result = authenticateAndPostToURL(remoteUrl+"/importFromXML", username, password, '%s.%s' % (i, 'xml'), xmlstring.encode('utf-8'))
 
     security.declarePrivate('importableDoc')
     def importableDoc(self, docId, lastEditRemoteDocumentDate, lastReplicationDate, whowins):
@@ -463,11 +466,11 @@ class PlominoReplicationManager(Persistent):
         return res
 
     security.declarePrivate('importDocumentPull')
-    def importDocumentPull(self, id, remoteUrl, username, password):
+    def importDocumentPull(self, i, remoteUrl, username, password):
         """ imports document from remoteurl
             send object as a .zexp stream via HTTP multipart POST
         """
-        f=authenticateAndLoadURL(remoteUrl+"/exportAsXML?docids="+id, username, password)
+        f=authenticateAndLoadURL(remoteUrl+"/exportAsXML?docids="+i, username, password)
         self.importFromXML(xmlstring=f.read())
 
     security.declareProtected(EDIT_PERMISSION, 'getReplications')
@@ -503,14 +506,14 @@ class PlominoReplicationManager(Persistent):
         return res
 
     security.declareProtected(EDIT_PERMISSION, 'getReplication')
-    def getReplication(self, id):
+    def getReplication(self, i):
         """returns the replication Id being edited
         """
         res = None
-        #replication list
+        # replication list
         replications = self.getReplications()
-        #serach id
-        searchId = str(id)
+        # search id
+        searchId = str(i)
         if replications.has_key(searchId):
             res = replications[searchId]
         return res
@@ -734,7 +737,7 @@ class PlominoReplicationManager(Persistent):
             raise PlominoReplicationException, "Request is required" 
 
         #params
-        id = REQUEST.get('replicationId', None)
+        i = REQUEST.get('replicationId', None)
         name = REQUEST.get('name', None)
         remoteUrl = REQUEST.get('remoteUrl', None)
         username = REQUEST.get('username', None)
@@ -746,13 +749,13 @@ class PlominoReplicationManager(Persistent):
         cron = REQUEST.get('cron', None)
         mode = REQUEST.get('mode', None)
 
-        return self.buildReplication(id, name, remoteUrl, username, password, repType, whoWins, scheduled, cron, restricttoview, mode)
+        return self.buildReplication(i, name, remoteUrl, username, password, repType, whoWins, scheduled, cron, restricttoview, mode)
 
     security.declarePrivate('createReplication')
-    def buildReplication(self, id, name, remoteUrl, username, password, repType, whoWins, scheduled, cron, restricttoview, mode):
+    def buildReplication(self, i, name, remoteUrl, username, password, repType, whoWins, scheduled, cron, restricttoview, mode):
         """return an empty replication
         """
-        return self.checkReplication({'id': id,
+        return self.checkReplication({'id': i,
                                     'name' : name,
                                     'remoteUrl' : remoteUrl,
                                     'username' : username,
@@ -1097,7 +1100,7 @@ class PlominoReplicationManager(Persistent):
         if docids is None:
             docs = self.getAllDocuments()
         else:
-            docs = [self.getDocument(id) for id in docids]
+            docs = [self.getDocument(i) for i in docids]
 
         if targettype == 'file':
             xmldoc = impl.createDocument(None, "plominodatabase", None)
@@ -1155,7 +1158,10 @@ class PlominoReplicationManager(Persistent):
 
         # export items
         str_items = xmlrpclib.dumps((doc.items,), allow_none=True)
-        dom_items = parseString(str_items)
+        try:
+            dom_items = parseString(str_items)
+        except ExpatError:
+            dom_items = parseString(escape_xml_illegal_chars(str_items))
         node.appendChild(dom_items.documentElement)
 
         # export attached files
@@ -1269,7 +1275,7 @@ class PlominoReplicationManager(Persistent):
             # convert xmlrpclib.DateTime into DateTime
             if items[k].__class__.__name__=='DateTime':
                 items[k]=StringToDate(items[k].value[:19], format="%Y-%m-%dT%H:%M:%S")
-        doc.items = items
+        doc.items = PersistentDict(items)
 
         # restore files
         for fnode in node.getElementsByTagName("attachment"):
