@@ -10,17 +10,28 @@
 __author__ = """Eric BREHAULT <eric.brehault@makina-corpus.com>"""
 __docformat__ = 'plaintext'
 
-from DateTime import DateTime
+# Standard
+from cStringIO import StringIO
+from email.Header import Header
+from email import message_from_string
 from time import strptime
-from Products.CMFCore.utils import getToolByName
-import htmlentitydefs as entity
-import urllib
+from types import StringTypes
 import cgi
 import csv
-from cStringIO import StringIO
+import decimal as std_decimal
+import Globals
+import htmlentitydefs as entity
 import Missing
-from email import message_from_string
-from email.Header import Header
+import re
+import urllib
+
+# Zope
+from AccessControl import ClassSecurityInfo
+from Acquisition import Implicit
+from DateTime import DateTime
+
+# Plone
+from Products.CMFCore.utils import getToolByName
 
 try:
     import json
@@ -70,7 +81,7 @@ def StringToDate(str_d, format='%Y-%m-%d'):
         dt = strptime(str_d, format)
     except ValueError, e:
         # XXX: Just let DateTime guess.
-        dt = strptime(DateTime(str_d).ISO(), '%Y-%m-%d %H:%M:%S')
+        dt = strptime(DateTime(str_d).ISO(), '%Y-%m-%dT%H:%M:%S')
         logger.info('StringToDate> %s, %s, %s, guessed: %s'%(str(str_d), format, `e`, `dt`))
     if len(dt) >= 5:
         return DateTime(dt[0], dt[1], dt[2], dt[3], dt[4])
@@ -196,7 +207,7 @@ def asList(x):
 
 
 def asUnicode(s):
-    """ Make sure ``s`` is unicode; encode according to site encoding if
+    """ Make sure ``s`` is unicode; decode according to site encoding if
     needed.
     """
     if not isinstance(s, basestring):
@@ -260,3 +271,31 @@ def json_dumps(obj):
 
 def json_loads(json_string):
     return json.loads(json_string)
+
+# From http://lsimons.wordpress.com/2011/03/17/stripping-illegal-characters-out-of-xml-in-python/
+_illegal_xml_chars_RE = re.compile(u'[\x00-\x08\x0b\x0c\x0e-\x1F\uD800-\uDFFF\uFFFE\uFFFF]')
+def escape_xml_illegal_chars(val, replacement='?'):
+    """Filter out characters that are illegal in XML.
+    Looks for any character in val that is not allowed in XML
+    and replaces it with replacement ('?' by default).
+    """
+    return _illegal_xml_chars_RE.sub(replacement, val)
+
+class plomino_decimal(std_decimal.Decimal, Implicit):
+    security = ClassSecurityInfo()
+    security.declareObjectPublic()
+    security.declarePublic('as_tuple')
+    security.declarePublic('quantize')
+
+Globals.InitializeClass(plomino_decimal)
+
+def decimal(v='0'):
+    """ Expose the standard library's Decimal class. Useful for finances.
+    """
+    if type(v) not in StringTypes:
+        v = str(v)
+    try:
+        v = plomino_decimal(v)
+        return v
+    except std_decimal.InvalidOperation:
+        return 'ERROR'
