@@ -17,6 +17,7 @@ from Products.Archetypes.atapi import *
 from zope.interface import implements
 import interfaces
 from Products.ATContentTypes.content.folder import ATFolder
+from plone.app.content.batching import Batch
 from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin
 
 from Products.CMFPlomino.config import *
@@ -60,13 +61,15 @@ schema = Schema((
     ),
     StringField(
         name='SortColumn',
-        widget=StringField._properties['widget'](
+        widget=SelectionWidget(
             label="Sort column",
             description="Column used to sort the view",
+            format='select',
             label_msgid='CMFPlomino_label_SortColumn',
             description_msgid='CMFPlomino_help_SortColumn',
             i18n_domain='CMFPlomino',
         ),
+        vocabulary="_getcolumn_ids",
         schemata="Sorting",
     ),
     BooleanField(
@@ -259,22 +262,28 @@ class PlominoView(ATFolder):
         return BaseObject.__bobo_traverse__(self, request, name)
 
     security.declarePublic('getAllDocuments')
-    def getAllDocuments(self, start=1, limit=None, only_allowed=True, getObject=True):
+    def getAllDocuments(self, start=1, limit=None, only_allowed=True, getObject=True, fulltext_query=None, sortindex=None, reverse=None):
         """ Return all the documents matching the view.
         """
-        # Ignore 'start': batching should be done using PloneBatch.
         index = self.getParentDatabase().getIndex()
-        sortindex = self.getSortColumn()
-        if sortindex=='':
-            sortindex=None
-        else:
-            sortindex=self.getIndexKey(sortindex)
+        if not sortindex:
+            sortindex = self.getSortColumn()
+            if sortindex=='':
+                sortindex=None
+            else:
+                sortindex=self.getIndexKey(sortindex)
+        if not reverse:
+            reverse = self.getReverseSorting()
+        query = {'PlominoViewFormula_'+self.getViewName() : True}
+        if fulltext_query:
+            query['SearchableText'] = fulltext_query
         results=index.dbsearch(
-            {'PlominoViewFormula_'+self.getViewName() : True},
-            sortindex,
-            self.getReverseSorting(),
-            only_allowed=only_allowed,
-            limit=limit)
+            query,
+            sortindex=sortindex,
+            reverse=reverse,
+            only_allowed=only_allowed)
+        if limit:
+            results = Batch(items=results, pagesize=limit, pagenumber=int(start/limit)+1)
         if getObject:
             return [r.getObject() for r in results]
         else:
@@ -295,13 +304,6 @@ class PlominoView(ATFolder):
         """Get colums
         """
         columnslist = self.portal_catalog.search({'portal_type' : ['PlominoColumn'], 'path': '/'.join(self.getPhysicalPath())}, sort_index='getObjPositionInParent')
-        #orderedcolumns = []
-        #for c in columnslist:
-        #    c_obj = c.getObject()
-        #    if not(c_obj is None):
-        #        orderedcolumns.append([c_obj.Position, c_obj])
-        #orderedcolumns.sort()
-        #return [i[1] for i in orderedcolumns]
         return [c.getObject() for c in columnslist]
 
     security.declarePublic('getActions')
@@ -380,7 +382,10 @@ class PlominoView(ATFolder):
                 if field:
                     field.setToBeIndexed(True)
                     #field.at_post_edit_script()
-                    index.createFieldIndex(field.id, field.getFieldType(), refresh=refresh)
+                    index.createFieldIndex(field.id,
+                                           field.getFieldType(),
+                                           refresh=refresh,
+                                           indextype=field.getIndexType())
                 else:
                     column_obj.setFormula("'Non-existing field'")
                     index.createIndex('PlominoViewColumn_'+self.getViewName()+'_'+column_name, refresh=refresh)
@@ -563,14 +568,42 @@ class PlominoView(ATFolder):
             return results
 
     security.declarePublic('tojson')
-    def tojson(self):
-        """Returns a JSON representation of view data 
+    def tojson(self, REQUEST=None):
+        """ Returns a JSON representation of view data 
         """
         data = []
         categorized = self.getCategorized()
-        
+        start = 1
+        limit = -1
+        search = None
+        sort_index = None
+        if REQUEST:
+            start = int(REQUEST.get('iDisplayStart', 1))
+            iDisplayLength = REQUEST.get('iDisplayLength', None)
+            if iDisplayLength:
+                limit = int(iDisplayLength)
+            search = REQUEST.get('sSearch', '').lower()
+            if search:
+                search = " ".join([term+'*' for term in search.split(' ')])
+            sort_column = REQUEST.get('iSortCol_0')
+            if sort_column:
+                sort_index = self.getIndexKey(self.getColumns()[int(sort_column)-1].id)
+            reverse = REQUEST.get('sSortDir_0', None)
+            if reverse=='desc':
+                reverse = 0
+            if reverse=='asc':
+                reverse = 1 
+        if limit < 1:
+            limit = None
+        results = self.getAllDocuments(start=start,
+                                       limit=limit,
+                                       getObject=False,
+                                       fulltext_query=search,
+                                       sortindex=sort_index,
+                                       reverse=reverse)
+        total = display_total = len(results)
         columnids = [col.id for col in self.getColumns() if not getattr(col, 'HiddenColumn', False)]
-        for b in self.getAllDocuments(getObject=False):
+        for b in results:
             row = [b.getPath().split('/')[-1]]
             for colid in columnids:
                 v = getattr(b, self.getIndexKey(colid), '')
@@ -579,7 +612,6 @@ class PlominoView(ATFolder):
                 else:
                     v = asUnicode(v).encode('utf-8').replace('\r', '')
                 row.append(v or '&nbsp;')
-
             if categorized:
                 for cat in asList(row[1]):
                     entry = [c for c in row]
@@ -587,12 +619,14 @@ class PlominoView(ATFolder):
                     data.append(entry)
             else:
                 data.append(row)
-        return json.dumps({ 'aaData': data })
+        return json.dumps({ 'iTotalRecords': total, 'iTotalDisplayRecords': display_total, 'aaData': data })
 
     security.declarePublic('getIndexKey')
     def getIndexKey(self, columnName):
-        """Returns an index key depending of which one exists.
-        It can be a computed index (PlominoViewColumn_) or a link to a column. 
+        """ Returns an index key if one exists.
+
+        We try to find a computed index ('PlominoViewColumn_*'); 
+        if not found, we look for a field.
         """
         key = 'PlominoViewColumn_%s_%s' % (self.getViewName(), columnName)
         if key not in self.getParentDatabase().plomino_index.Indexes:
@@ -603,9 +637,8 @@ class PlominoView(ATFolder):
                 key = ''
         return key
 
-
+    def _getcolumn_ids(self):
+        return [''] +  [c.id for c in self.getColumns()]
+        
 registerType(PlominoView, PROJECTNAME)
 # end of class PlominoView
-
-
-
